aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Teichmann <daniel.teichmann@das-netzwerkteam.de>2021-07-01 21:26:44 +0200
committerDaniel Teichmann <daniel.teichmann@das-netzwerkteam.de>2021-07-01 21:26:44 +0200
commit94cb2b582e2ae774d7e61237ea9c6ecde212a872 (patch)
tree54573a5af9dea39ae7818e7cbd82c4c869c7f312
parent9445811741b4e74348a822399d881f7e6d93275d (diff)
downloadRWA.Support.SessionService-94cb2b582e2ae774d7e61237ea9c6ecde212a872.tar.gz
RWA.Support.SessionService-94cb2b582e2ae774d7e61237ea9c6ecde212a872.tar.bz2
RWA.Support.SessionService-94cb2b582e2ae774d7e61237ea9c6ecde212a872.zip
test_client.py: Update docstrings
-rwxr-xr-xtest_client.py48
1 files changed, 24 insertions, 24 deletions
diff --git a/test_client.py b/test_client.py
index 4a0f83a..bb54500 100755
--- a/test_client.py
+++ b/test_client.py
@@ -44,8 +44,8 @@ def cli():
@cli.command()
def get_web_app_hosts():
- """Start a session on the RWA.Support.WebApp host with index HOST."""
- click.echo("Sending D-Bus request 'get_web_app_hosts'")
+ """Get all RWA.Support.WebApp hosts"""
+ click.echo("Sending D-Bus request 'get_web_app_hosts.'")
response = req.get_web_app_hosts()
click.echo(f"Your response is: {response}")
@@ -53,7 +53,7 @@ def get_web_app_hosts():
@cli.command()
@click.argument("host", type=str)
def add_web_app_host(host: str):
- """Start a session on the RWA.Support.WebApp host with index HOST."""
+ """Add a RWA.Support.WebApp host. Requires <url>"""
click.echo(f"Sending D-Bus request 'add_web_app_host': {host}")
response = req.add_web_app_host(host)
click.echo(f"Your response is: {response}")
@@ -62,50 +62,50 @@ def add_web_app_host(host: str):
@cli.command()
@click.argument("host", type=str)
def remove_web_app_host(host: str):
- """Start a session on the RWA.Support.WebApp host with index HOST."""
+ """Remove a RWA.Support.WebApp host. Requires <url>"""
click.echo(f"Sending D-Bus request 'remove_web_app_host': {host}")
response = req.remove_web_app_host(host)
click.echo(f"Your response is: {response}")
@cli.command()
-@click.argument("host_id", type=str)
-def start(host_id: str):
- """Start a session on the RWA.Support.WebApp host with index HOST."""
- click.echo(f"Sending D-Bus request 'start': {host_id}")
- response = req.start(host_id)
+@click.argument("host_uuid", type=str)
+def start(host_uuid: str):
+ """Start a session on the RWA.Support.WebApp host. Requires <host_uuid>"""
+ click.echo(f"Sending D-Bus request 'start': {host_uuid}")
+ response = req.start(host_uuid)
click.echo(f"Your response is: {response}")
@cli.command()
-@click.argument("host_id", type=str)
+@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
-def stop(host_id: str, session_id: int):
- """Stop the session with the pid PID."""
- click.echo(f"Sending D-Bus request 'stop' with host ID {host_id} and session ID {session_id}")
- response = req.stop(host_id, session_id)
+def stop(host_uuid: str, session_id: int):
+ """Stop a session on the RWA.Support.WebApp host. Requires <host_uuid> <session_id>"""
+ click.echo(f"Sending D-Bus request 'stop' with host ID {host_uuid} and session ID {session_id}")
+ response = req.stop(host_uuid, session_id)
click.echo(f"Your response is: {response}")
@cli.command()
-@click.argument("host_id", type=str)
+@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
-def status(host_id: str, session_id: int):
- """Get the status of the session with the pid PID."""
- click.echo(f"Sending D-Bus request 'status' with host ID {host_id} and session ID {session_id}")
- response = req.status(host_id, session_id)
+def status(host_uuid: str, session_id: int):
+ """Get the status of a session. Requires <host_uuid> <session_id>"""
+ click.echo(f"Sending D-Bus request 'status' with host ID {host_uuid} and session ID {session_id}")
+ response = req.status(host_uuid, session_id)
click.echo(f"Your response is: {response}")
@cli.command()
-@click.argument("host_id", type=str)
+@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
-def refresh_status(host_id: str, session_id: int):
- """Refresh and get the status of the session with the pid PID."""
+def refresh_status(host_uuid: str, session_id: int):
+ """Refresh and then get the status of a session. Requires <host_uuid> <session_id>"""
click.echo(
- f"Sending D-Bus request 'refresh_status' with host ID {host_id} and session ID {session_id}"
+ f"Sending D-Bus request 'refresh_status' with host ID {host_uuid} and session ID {session_id}"
)
- response = req.refresh_status(host_id, session_id)
+ response = req.refresh_status(host_uuid, session_id)
click.echo(f"Your response is: {response}")